@@ -130,6 +130,18 @@ class Webapp:
         url = get_api_endpoint().format(username=getpass.getuser(), flavor="webapps") + self.domain + "/reload/"
         response = call_api(url, "post")
         if not response.ok:
+            if response.status_code == 409 and response.json()["error"] == "cname_error":
+                print(
+                    snakesay(
+                        dedent("""
+                            Could not find a CNAME for your website.  If you're using an A record,
+                            CloudFlare, or some other way of pointing your domain at PythonAnywhere
+                            then that should not be a problem.  If you're not, you should double-check
+                            your DNS setup.
+                        """)
+                    )
+                )
+                return
             raise Exception(
                 "POST to reload webapp via API failed, got {response}:{response_text}".format(
                     response=response, response_text=response.text
@@ -145,8 +157,8 @@ class Webapp:
                 dedent(
                     """
                     POST to set SSL details via API failed, got {response}:{response_text}
-                    If you just created an API token, you need to set the API_TOKEN environment variable or start a new console.
-                    Also you need to have setup a `{domain}` PythonAnywhere webapp for this to work.
+                    If you just created an API token, you need to set the API_TOKEN environment variable or start a
+                    new console.  Also you need to have setup a `{domain}` PythonAnywhere webapp for this to work.
                     """
                 ).format(response=response, response_text=response.text, domain=self.domain)
             )
@@ -216,7 +228,7 @@ class Webapp:
         log_prefix = "/var/log/{domain}.".format(domain=self.domain)
         for file_name in file_list:
             if type(file_name) == str and file_name.startswith(log_prefix):
-                log = file_name[len(log_prefix) :].split(".")
+                log = file_name[len(log_prefix):].split(".")
                 if log[0] in log_types:
                     log_type = log[0]
                     if log[-1] == "log":
